@@ -53,8 +53,6 @@
  */
 
 #include <stdio.h>
-#include <inttypes.h>
-#include <stdbool.h>
 
 #include <isc/lang.h>
 #include <isc/magic.h>
@@ -88,7 +86,6 @@ struct dns_view {
 	dns_resolver_t *		resolver;
 	dns_adb_t *			adb;
 	dns_requestmgr_t *		requestmgr;
-	dns_acache_t *			acache;
 	dns_cache_t *			cache;
 	dns_db_t *			cachedb;
 	dns_db_t *			hints;
@@ -101,7 +98,7 @@ struct dns_view {
 	dns_ntatable_t *		ntatable_priv;
 
 	isc_mutex_t			lock;
-	bool			frozen;
+	isc_boolean_t			frozen;
 	isc_task_t *			task;
 	isc_event_t			resevent;
 	isc_event_t			adbevent;
@@ -109,7 +106,7 @@ struct dns_view {
 	isc_stats_t *			adbstats;
 	isc_stats_t *			resstats;
 	dns_stats_t *			resquerystats;
-	bool			cacheshared;
+	isc_boolean_t			cacheshared;
 
 	/* Configurable data. */
 	dns_tsig_keyring_t *		statickeys;
@@ -117,18 +114,18 @@ struct dns_view {
 	dns_peerlist_t *		peers;
 	dns_order_t *			order;
 	dns_fwdtable_t *		fwdtable;
-	bool			recursion;
-	bool			auth_nxdomain;
-	bool			additionalfromcache;
-	bool			additionalfromauth;
-	bool			minimal_any;
+	isc_boolean_t			recursion;
+	isc_boolean_t			auth_nxdomain;
+	isc_boolean_t			use_glue_cache;
+	isc_boolean_t			minimal_any;
 	dns_minimaltype_t		minimalresponses;
-	bool			enablednssec;
-	bool			enablevalidation;
-	bool			acceptexpired;
-	bool			requireservercookie;
-	bool			trust_anchor_telemetry;
-	bool			root_key_sentinel;
+	isc_boolean_t			enablednssec;
+	isc_boolean_t			enablevalidation;
+	isc_boolean_t			acceptexpired;
+	isc_boolean_t			requireservercookie;
+	isc_boolean_t			synthfromdnssec;
+	isc_boolean_t			trust_anchor_telemetry;
+	isc_boolean_t			root_key_sentinel;
 	dns_transfer_format_t		transfer_format;
 	dns_acl_t *			cacheacl;
 	dns_acl_t *			cacheonacl;
@@ -143,33 +140,38 @@ struct dns_view {
 	dns_acl_t *			upfwdacl;
 	dns_acl_t *			denyansweracl;
 	dns_acl_t *			nocasecompress;
-	bool			msgcompression;
+	isc_boolean_t			msgcompression;
 	dns_rbt_t *			answeracl_exclude;
 	dns_rbt_t *			denyanswernames;
 	dns_rbt_t *			answernames_exclude;
 	dns_rrl_t *			rrl;
-	bool			provideixfr;
-	bool			requestnsid;
-	bool			sendcookie;
+	isc_boolean_t			provideixfr;
+	isc_boolean_t			requestnsid;
+	isc_boolean_t			sendcookie;
 	dns_ttl_t			maxcachettl;
 	dns_ttl_t			maxncachettl;
-	uint32_t			nta_lifetime;
-	uint32_t			nta_recheck;
+	isc_uint32_t			nta_lifetime;
+	isc_uint32_t			nta_recheck;
 	char				*nta_file;
 	dns_ttl_t			prefetch_trigger;
 	dns_ttl_t			prefetch_eligible;
 	in_port_t			dstport;
 	dns_aclenv_t			aclenv;
 	dns_rdatatype_t			preferred_glue;
-	bool			flush;
+	isc_boolean_t			flush;
 	dns_namelist_t *		delonly;
-	bool			rootdelonly;
+	isc_boolean_t			rootdelonly;
 	dns_namelist_t *		rootexclude;
-	bool			checknames;
+	isc_boolean_t			checknames;
 	dns_name_t *			dlv;
 	dns_fixedname_t			dlv_fixed;
-	uint16_t			maxudp;
-	uint16_t			nocookieudp;
+	isc_uint16_t			maxudp;
+	dns_ttl_t			staleanswerttl;
+	dns_stale_answer_t		staleanswersok;		/* rndc setting */
+	isc_boolean_t			staleanswersenable;	/* named.conf setting */
+	isc_uint16_t			nocookieudp;
+	isc_uint16_t			padding;
+	dns_acl_t *			pad_acl;
 	unsigned int			maxbits;
 	dns_aaaa_t			v4_aaaa;
 	dns_aaaa_t			v6_aaaa;
@@ -180,7 +182,7 @@ struct dns_view {
 	dns_catz_zones_t		*catzs;
 	dns_dlzdblist_t 		dlz_searched;
 	dns_dlzdblist_t 		dlz_unsearched;
-	uint32_t			fail_ttl;
+	isc_uint32_t			fail_ttl;
 	dns_badcache_t			*failcache;
 
 	/*
@@ -189,7 +191,7 @@ struct dns_view {
 	 */
 	dns_acl_t *			matchclients;
 	dns_acl_t *			matchdestinations;
-	bool			matchrecursiveonly;
+	isc_boolean_t			matchrecursiveonly;
 
 	/* Locked by themselves. */
 	isc_refcount_t			references;
@@ -215,10 +217,11 @@ struct dns_view {
 	 * XXX: This should be a pointer to an opaque type that
 	 * named implements.
 	 */
+	char *				new_zone_dir;
 	char *				new_zone_file;
-	char *			        new_zone_db;
+	char *				new_zone_db;
 	void *				new_zone_dbenv;
-	uint64_t			new_zone_mapsize;
+	isc_uint64_t			new_zone_mapsize;
 	void *				new_zone_config;
 	void				(*cfg_destroy)(void **);
 	isc_mutex_t			new_zone_lock;
@@ -416,11 +419,11 @@ dns_view_createresolver(dns_view_t *view,
 void
 dns_view_setcache(dns_view_t *view, dns_cache_t *cache);
 void
-dns_view_setcache2(dns_view_t *view, dns_cache_t *cache, bool shared);
+dns_view_setcache2(dns_view_t *view, dns_cache_t *cache, isc_boolean_t shared);
 /*%<
  * Set the view's cache database.  If 'shared' is true, this means the cache
  * is created by another view and is shared with that view.  dns_view_setcache()
- * is a backward compatible version equivalent to setcache2(..., false).
+ * is a backward compatible version equivalent to setcache2(..., ISC_FALSE).
  *
  * Requires:
  *
@@ -545,14 +548,14 @@ dns_view_thaw(dns_view_t *view);
  *\li	'view' is no longer frozen.
  */
 isc_result_t
-dns_view_find(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
-	      isc_stdtime_t now, unsigned int options, bool use_hints,
+dns_view_find(dns_view_t *view, const dns_name_t *name, dns_rdatatype_t type,
+	      isc_stdtime_t now, unsigned int options, isc_boolean_t use_hints,
 	      dns_db_t **dbp, dns_dbnode_t **nodep, dns_name_t *foundname,
 	      dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset);
 isc_result_t
-dns_view_find2(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
+dns_view_find2(dns_view_t *view, const dns_name_t *name, dns_rdatatype_t type,
 	       isc_stdtime_t now, unsigned int options,
-	       bool use_hints, bool use_static_stub,
+	       isc_boolean_t use_hints, isc_boolean_t use_static_stub,
 	       dns_db_t **dbp, dns_dbnode_t **nodep, dns_name_t *foundname,
 	       dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset);
 /*%<
@@ -560,13 +563,13 @@ dns_view_find2(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
  * 'type'.
  * In general, this function first searches view's zone and cache DBs for the
  * best match data against 'name'.  If nothing found there, and if 'use_hints'
- * is true, the view's hint DB (if configured) is searched.
+ * is ISC_TRUE, the view's hint DB (if configured) is searched.
  * If the view is configured with a static-stub zone which gives the longest
  * match for 'name' among the zones, however, the cache DB is not consulted
- * unless 'use_static_stub' is false (see below about this argument).
+ * unless 'use_static_stub' is ISC_FALSE (see below about this argument).
  *
  * dns_view_find() is a backward compatible version equivalent to
- * dns_view_find2() with use_static_stub argument being false.
+ * dns_view_find2() with use_static_stub argument being ISC_FALSE.
  *
  * Notes:
  *
@@ -576,16 +579,16 @@ dns_view_find2(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
  *
  *\li	If 'now' is zero, then the current time will be used.
  *
- *\li	If 'use_hints' is true, and the view has a hints database, then
+ *\li	If 'use_hints' is ISC_TRUE, and the view has a hints database, then
  *	it will be searched last.  If the answer is found in the hints
  *	database, the result code will be DNS_R_HINT.  If the name is found
  *	in the hints database but not the type, the result code will be
  *	#DNS_R_HINTNXRRSET.
  *
- *\li	If 'use_static_stub' is false and the longest match zone for 'name'
+ *\li	If 'use_static_stub' is ISC_FALSE and the longest match zone for 'name'
  *	is a static-stub zone, it's ignored and the cache and/or hints will be
  *	searched.  In the majority of the cases this argument should be
- *	false.  The only known usage of this argument being true is
+ *	ISC_FALSE.  The only known usage of this argument being ISC_TRUE is
  *	if this search is for a "bailiwick" glue A or AAAA RRset that may
  *	best match a static-stub zone.  Consider the following example:
  *	this view is configured with a static-stub zone "example.com",
@@ -641,9 +644,9 @@ dns_view_find2(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
  */
 
 isc_result_t
-dns_view_simplefind(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
-		    isc_stdtime_t now, unsigned int options,
-		    bool use_hints,
+dns_view_simplefind(dns_view_t *view, const dns_name_t *name,
+		    dns_rdatatype_t type, isc_stdtime_t now,
+		    unsigned int options, isc_boolean_t use_hints,
 		    dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset);
 /*%<
  * Find an rdataset whose owner name is 'name', and whose type is
@@ -661,7 +664,7 @@ dns_view_simplefind(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
  *
  *\li	If 'now' is zero, then the current time will be used.
  *
- *\li	If 'use_hints' is true, and the view has a hints database, then
+ *\li	If 'use_hints' is ISC_TRUE, and the view has a hints database, then
  *	it will be searched last.  If the answer is found in the hints
  *	database, the result code will be DNS_R_HINT.  If the name is found
  *	in the hints database but not the type, the result code will be
@@ -703,15 +706,16 @@ dns_view_simplefind(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
 
 /*% See dns_view_findzonecut2() */
 isc_result_t
-dns_view_findzonecut(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
-		     isc_stdtime_t now, unsigned int options,
-		     bool use_hints,
+dns_view_findzonecut(dns_view_t *view, const dns_name_t *name,
+		     dns_name_t *fname, isc_stdtime_t now,
+		     unsigned int options, isc_boolean_t use_hints,
 		     dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset);
 
 isc_result_t
-dns_view_findzonecut2(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
-		      isc_stdtime_t now, unsigned int options,
-		      bool use_hints, bool use_cache,
+dns_view_findzonecut2(dns_view_t *view, const dns_name_t *name,
+		      dns_name_t *fname, isc_stdtime_t now,
+		      unsigned int options,
+		      isc_boolean_t use_hints, isc_boolean_t use_cache,
 		      dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset);
 /*%<
  * Find the best known zonecut containing 'name'.
@@ -723,10 +727,10 @@ dns_view_findzonecut2(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
  *
  *\li	If 'now' is zero, then the current time will be used.
  *
- *\li	If 'use_hints' is true, and the view has a hints database, then
+ *\li	If 'use_hints' is ISC_TRUE, and the view has a hints database, then
  *	it will be searched last.
  *
- *\li	If 'use_cache' is true, and the view has a cache, then it will be
+ *\li	If 'use_cache' is ISC_TRUE, and the view has a cache, then it will be
  *	searched.
  *
  *\li	If 'sigrdataset' is not NULL, and there is a SIG rdataset which
@@ -770,8 +774,9 @@ dns_viewlist_find(dns_viewlist_t *list, const char *name,
  */
 
 isc_result_t
-dns_viewlist_findzone(dns_viewlist_t *list, dns_name_t *name, bool allclasses,
-		      dns_rdataclass_t rdclass, dns_zone_t **zonep);
+dns_viewlist_findzone(dns_viewlist_t *list, const dns_name_t *name,
+		      isc_boolean_t allclasses, dns_rdataclass_t rdclass,
+		      dns_zone_t **zonep);
 
 /*%<
  * Search zone with 'name' in view with 'rdclass' in viewlist 'list'
@@ -784,7 +789,8 @@ dns_viewlist_findzone(dns_viewlist_t *list, dns_name_t *name, bool allclasses,
  */
 
 isc_result_t
-dns_view_findzone(dns_view_t *view, dns_name_t *name, dns_zone_t **zonep);
+dns_view_findzone(dns_view_t *view, const dns_name_t *name,
+		  dns_zone_t **zonep);
 /*%<
  * Search for the zone 'name' in the zone table of 'view'.
  * If found, 'zonep' is (strongly) attached to it.  There
@@ -801,17 +807,13 @@ dns_view_findzone(dns_view_t *view, dns_name_t *name, dns_zone_t **zonep);
  */
 
 isc_result_t
-dns_view_load(dns_view_t *view, bool stop);
+dns_view_load(dns_view_t *view, isc_boolean_t stop);
 
 isc_result_t
-dns_view_loadnew(dns_view_t *view, bool stop);
+dns_view_loadnew(dns_view_t *view, isc_boolean_t stop);
 
 isc_result_t
 dns_view_asyncload(dns_view_t *view, dns_zt_allloaded_t callback, void *arg);
-
-isc_result_t
-dns_view_asyncload2(dns_view_t *view, dns_zt_allloaded_t callback, void *arg,
-		    bool newonly);
 /*%<
  * Load zones attached to this view.  dns_view_load() loads
  * all zones whose master file has changed since the last
@@ -822,8 +824,8 @@ dns_view_asyncload2(dns_view_t *view, dns_zt_allloaded_t callback, void *arg,
  * in the view have finished loading, 'callback' is called with argument
  * 'arg' to inform the caller.
  *
- * If 'stop' is true, stop on the first error and return it.
- * If 'stop' is false (or we are loading asynchronously), ignore errors.
+ * If 'stop' is ISC_TRUE, stop on the first error and return it.
+ * If 'stop' is ISC_FALSE (or we are loading asynchronously), ignore errors.
  *
  * Requires:
  *
@@ -831,7 +833,7 @@ dns_view_asyncload2(dns_view_t *view, dns_zt_allloaded_t callback, void *arg,
  */
 
 isc_result_t
-dns_view_gettsig(dns_view_t *view, dns_name_t *keyname,
+dns_view_gettsig(dns_view_t *view, const dns_name_t *keyname,
 		 dns_tsigkey_t **keyp);
 /*%<
  * Find the TSIG key configured in 'view' with name 'keyname',
@@ -847,7 +849,7 @@ dns_view_gettsig(dns_view_t *view, dns_name_t *keyname,
  */
 
 isc_result_t
-dns_view_getpeertsig(dns_view_t *view, isc_netaddr_t *peeraddr,
+dns_view_getpeertsig(dns_view_t *view, const isc_netaddr_t *peeraddr,
 		     dns_tsigkey_t **keyp);
 /*%<
  * Find the TSIG key configured in 'view' for the server whose
@@ -908,7 +910,7 @@ dns_view_dumpdbtostream(dns_view_t *view, FILE *fp);
 isc_result_t
 dns_view_flushcache(dns_view_t *view);
 isc_result_t
-dns_view_flushcache2(dns_view_t *view, bool fixuponly);
+dns_view_flushcache2(dns_view_t *view, isc_boolean_t fixuponly);
 /*%<
  * Flush the view's cache (and ADB).  If 'fixuponly' is true, it only updates
  * the internal reference to the cache DB with omitting actual flush operation.
@@ -927,7 +929,8 @@ dns_view_flushcache2(dns_view_t *view, bool fixuponly);
  */
 
 isc_result_t
-dns_view_flushnode(dns_view_t *view, dns_name_t *name, bool tree);
+dns_view_flushnode(dns_view_t *view, const dns_name_t *name,
+		   isc_boolean_t tree);
 /*%<
  * Flush the given name from the view's cache (and optionally ADB/badcache).
  *
@@ -944,10 +947,10 @@ dns_view_flushnode(dns_view_t *view, dns_name_t *name, bool tree);
  */
 
 isc_result_t
-dns_view_flushname(dns_view_t *view, dns_name_t *name);
+dns_view_flushname(dns_view_t *view, const dns_name_t *name);
 /*%<
  * Flush the given name from the view's cache, ADB and badcache.
- * Equivalent to dns_view_flushnode(view, name, false).
+ * Equivalent to dns_view_flushnode(view, name, ISC_FALSE).
  *
  *
  * Requires:
@@ -960,7 +963,7 @@ dns_view_flushname(dns_view_t *view, dns_name_t *name);
  */
 
 isc_result_t
-dns_view_adddelegationonly(dns_view_t *view, dns_name_t *name);
+dns_view_adddelegationonly(dns_view_t *view, const dns_name_t *name);
 /*%<
  * Add the given name to the delegation only table.
  *
@@ -974,7 +977,7 @@ dns_view_adddelegationonly(dns_view_t *view, dns_name_t *name);
  */
 
 isc_result_t
-dns_view_excludedelegationonly(dns_view_t *view, dns_name_t *name);
+dns_view_excludedelegationonly(dns_view_t *view, const dns_name_t *name);
 /*%<
  * Add the given name to be excluded from the root-delegation-only.
  *
@@ -988,8 +991,8 @@ dns_view_excludedelegationonly(dns_view_t *view, dns_name_t *name);
  *\li	#ISC_R_NOMEMORY
  */
 
-bool
-dns_view_isdelegationonly(dns_view_t *view, dns_name_t *name);
+isc_boolean_t
+dns_view_isdelegationonly(dns_view_t *view, const dns_name_t *name);
 /*%<
  * Check if 'name' is in the delegation only table or if
  * rootdelonly is set that name is not being excluded.
@@ -999,12 +1002,12 @@ dns_view_isdelegationonly(dns_view_t *view, dns_name_t *name);
  *\li	'name' is valid.
  *
  * Returns:
- *\li	#true if the name is the table.
- *\li	#false otherwise.
+ *\li	#ISC_TRUE if the name is the table.
+ *\li	#ISC_FALSE otherwise.
  */
 
 void
-dns_view_setrootdelonly(dns_view_t *view, bool value);
+dns_view_setrootdelonly(dns_view_t *view, isc_boolean_t value);
 /*%<
  * Set the root delegation only flag.
  *
@@ -1012,7 +1015,7 @@ dns_view_setrootdelonly(dns_view_t *view, bool value);
  *\li	'view' is valid.
  */
 
-bool
+isc_boolean_t
 dns_view_getrootdelonly(dns_view_t *view);
 /*%<
  * Get the root delegation only flag.
@@ -1022,7 +1025,7 @@ dns_view_getrootdelonly(dns_view_t *view);
  */
 
 isc_result_t
-dns_view_freezezones(dns_view_t *view, bool freeze);
+dns_view_freezezones(dns_view_t *view, isc_boolean_t freeze);
 /*%<
  * Freeze/thaw updates to master zones.
  *
@@ -1106,7 +1109,7 @@ dns_view_getresquerystats(dns_view_t *view, dns_stats_t **statsp);
  *\li	'statsp' != NULL && '*statsp' != NULL
  */
 
-bool
+isc_boolean_t
 dns_view_iscacheshared(dns_view_t *view);
 /*%<
  * Check if the view shares the cache created by another view.
@@ -1115,8 +1118,8 @@ dns_view_iscacheshared(dns_view_t *view);
  * \li	'view' is valid.
  *
  * Returns:
- *\li	#true if the cache is shared.
- *\li	#false otherwise.
+ *\li	#ISC_TRUE if the cache is shared.
+ *\li	#ISC_FALSE otherwise.
  */
 
 isc_result_t
@@ -1188,14 +1191,14 @@ dns_view_getsecroots(dns_view_t *view, dns_keytable_t **ktp);
  */
 
 isc_result_t
-dns_view_issecuredomain(dns_view_t *view, dns_name_t *name,
-			isc_stdtime_t now, bool checknta,
-			bool *secure_domain);
+dns_view_issecuredomain(dns_view_t *view, const dns_name_t *name,
+			isc_stdtime_t now, isc_boolean_t checknta,
+			isc_boolean_t *secure_domain);
 /*%<
  * Is 'name' at or beneath a trusted key, and not covered by a valid
  * negative trust anchor?  Put answer in '*secure_domain'.
  *
- * If 'checknta' is false, ignore the NTA table in determining
+ * If 'checknta' is ISC_FALSE, ignore the NTA table in determining
  * whether this is a secure domain.
  *
  * Requires:
@@ -1206,9 +1209,9 @@ dns_view_issecuredomain(dns_view_t *view, dns_name_t *name,
  *\li	Any other value indicates failure
  */
 
-bool
+isc_boolean_t
 dns_view_ntacovers(dns_view_t *view, isc_stdtime_t now,
-		   dns_name_t *name, dns_name_t *anchor);
+		   const dns_name_t *name, const dns_name_t *anchor);
 /*%<
  * Is there a current negative trust anchor above 'name' and below 'anchor'?
  *
@@ -1221,7 +1224,7 @@ dns_view_ntacovers(dns_view_t *view, isc_stdtime_t now,
  */
 
 void
-dns_view_untrust(dns_view_t *view, dns_name_t *keyname,
+dns_view_untrust(dns_view_t *view, const dns_name_t *keyname,
 		 dns_rdata_dnskey_t *dnskey, isc_mem_t *mctx);
 /*%<
  * Remove keys that match 'keyname' and 'dnskey' from the views trust
@@ -1241,12 +1244,12 @@ dns_view_untrust(dns_view_t *view, dns_name_t *keyname,
  */
 
 isc_result_t
-dns_view_setnewzones(dns_view_t *view, bool allow, void *cfgctx,
-		     void (*cfg_destroy)(void **), uint64_t mapsize);
+dns_view_setnewzones(dns_view_t *view, isc_boolean_t allow, void *cfgctx,
+		     void (*cfg_destroy)(void **), isc_uint64_t mapsize);
 /*%<
  * Set whether or not to allow zones to be created or deleted at runtime.
  *
- * If 'allow' is true, determines the filename into which new zone
+ * If 'allow' is ISC_TRUE, determines the filename into which new zone
  * configuration will be written.  Preserves the configuration context
  * (a pointer to which is passed in 'cfgctx') for use when parsing new
  * zone configuration.  'cfg_destroy' points to a callback routine to
@@ -1254,7 +1257,7 @@ dns_view_setnewzones(dns_view_t *view, bool allow, void *cfgctx,
  * roundabout method is used in order to avoid libdns having a dependency
  * on libisccfg and libbind9.)
  *
- * If 'allow' is false, removes any existing references to
+ * If 'allow' is ISC_FALSE, removes any existing references to
  * configuration context and frees any memory.
  *
  * Requires:
@@ -1265,11 +1268,24 @@ dns_view_setnewzones(dns_view_t *view, bool allow, void *cfgctx,
  * \li ISC_R_NOSPACE
  */
 
+void
+dns_view_setnewzonedir(dns_view_t *view, const char *dir);
+const char *
+dns_view_getnewzonedir(dns_view_t *view);
+/*%<
+ * Set/get the path to the directory in which NZF or NZD files should
+ * be stored. If the path was previously set to a non-NULL value,
+ * the previous value is freed.
+ *
+ * Requires:
+ * \li 'view' is valid.
+ */
+
 void
 dns_view_restorekeyring(dns_view_t *view);
 
 isc_result_t
-dns_view_searchdlz(dns_view_t *view, dns_name_t *name,
+dns_view_searchdlz(dns_view_t *view, const dns_name_t *name,
 		   unsigned int minlabels,
 		   dns_clientinfomethods_t *methods,
 		   dns_clientinfo_t *clientinfo,
@@ -1291,7 +1307,7 @@ dns_view_searchdlz(dns_view_t *view, dns_name_t *name,
  * \li 'dbp' is not NULL and *dbp is NULL.
  */
 
-uint32_t
+isc_uint32_t
 dns_view_getfailttl(dns_view_t *view);
 /*%<
  * Get the view's servfail-ttl.  zero => no servfail caching.
@@ -1301,7 +1317,7 @@ dns_view_getfailttl(dns_view_t *view);
  */
 
 void
-dns_view_setfailttl(dns_view_t *view, uint32_t failttl);
+dns_view_setfailttl(dns_view_t *view, isc_uint32_t failttl);
 /*%<
  * Set the view's servfail-ttl.  zero => no servfail caching.
  *
