@@ -197,7 +197,7 @@ digest_in_dhcid(ARGS_DIGEST) {
 	return ((digest)(arg, &r));
 }
 
-static inline bool
+static inline isc_boolean_t
 checkowner_in_dhcid(ARGS_CHECKOWNER) {
 
 	REQUIRE(type == dns_rdatatype_dhcid);
@@ -208,10 +208,10 @@ checkowner_in_dhcid(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
-static inline bool
+static inline isc_boolean_t
 checknames_in_dhcid(ARGS_CHECKNAMES) {
 
 	REQUIRE(rdata->type == dns_rdatatype_dhcid);
@@ -221,7 +221,7 @@ checknames_in_dhcid(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 static inline int
