@@ -1,21 +1,14 @@
 /*
- * Copyright (C) 2004-2007  Internet Systems Consortium, Inc. ("ISC")
- * Copyright (C) 2000-2003  Internet Software Consortium.
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id: entropy.c,v 1.18 2007/06/19 23:47:17 tbox Exp $ */
 
 /*! \file
  * \brief
@@ -40,12 +33,17 @@
 #include <isc/msgs.h>
 #include <isc/mutex.h>
 #include <isc/platform.h>
+#include <isc/print.h>
 #include <isc/region.h>
+#include <isc/safe.h>
 #include <isc/sha1.h>
 #include <isc/string.h>
 #include <isc/time.h>
 #include <isc/util.h>
 
+#ifdef PKCS11CRYPTO
+#include <pk11/pk11.h>
+#endif
 
 #define ENTROPY_MAGIC		ISC_MAGIC('E', 'n', 't', 'e')
 #define SOURCE_MAGIC		ISC_MAGIC('E', 'n', 't', 's')
@@ -105,11 +103,15 @@ struct isc_entropy {
 	isc_uint32_t			initialized;
 	isc_uint32_t			initcount;
 	isc_entropypool_t		pool;
+	isc_boolean_t			usehook;
 	unsigned int			nsources;
 	isc_entropysource_t	       *nextsource;
 	ISC_LIST(isc_entropysource_t)	sources;
 };
 
+/*% Global Hook */
+static isc_entropy_getdata_t hook;
+
 /*% Sample Queue */
 typedef struct {
 	isc_uint32_t	last_time;	/*%< last time recorded */
@@ -283,14 +285,17 @@ entropypool_add_word(isc_entropypool_t *rp, isc_uint32_t val) {
 	val ^= rp->pool[(rp->cursor + TAP3) & (RND_POOLWORDS - 1)];
 	val ^= rp->pool[(rp->cursor + TAP4) & (RND_POOLWORDS - 1)];
 	val ^= rp->pool[(rp->cursor + TAP5) & (RND_POOLWORDS - 1)];
-	rp->pool[rp->cursor++] ^=
-	  ((val << rp->rotate) | (val >> (32 - rp->rotate)));
+	if (rp->rotate == 0)
+		rp->pool[rp->cursor++] ^= val;
+	else
+		rp->pool[rp->cursor++] ^=
+		  ((val << rp->rotate) | (val >> (32 - rp->rotate)));
 
 	/*
 	 * If we have looped around the pool, increment the rotate
 	 * variable so the next value will get xored in rotated to
 	 * a different position.
-	 * Increment by a value that is relativly prime to the word size
+	 * Increment by a value that is relatively prime to the word size
 	 * to try to spread the bits throughout the pool quickly when the
 	 * pool is empty.
 	 */
@@ -313,7 +318,12 @@ entropypool_adddata(isc_entropy_t *ent, void *p, unsigned int len,
 	unsigned long addr;
 	isc_uint8_t *buf;
 
+	/* Silly MSVC in 64 bit mode complains here... */
+#ifdef _WIN64
+	addr = (unsigned long)((unsigned long long)p);
+#else
 	addr = (unsigned long)p;
+#endif
 	buf = p;
 
 	if ((addr & 0x03U) != 0U) {
@@ -322,9 +332,11 @@ entropypool_adddata(isc_entropy_t *ent, void *p, unsigned int len,
 		case 3:
 			val = *buf++;
 			len--;
+			/* FALLTHROUGH */
 		case 2:
 			val = val << 8 | *buf++;
 			len--;
+			/* FALLTHROUGH */
 		case 1:
 			val = val << 8 | *buf++;
 			len--;
@@ -345,8 +357,10 @@ entropypool_adddata(isc_entropy_t *ent, void *p, unsigned int len,
 		switch (len) {
 		case 3:
 			val = *buf++;
+			/* FALLTHROUGH */
 		case 2:
 			val = val << 8 | *buf++;
+			/* FALLTHROUGH */
 		case 1:
 			val = val << 8 | *buf++;
 		}
@@ -546,6 +560,11 @@ isc_entropy_getdata(isc_entropy_t *ent, void *data, unsigned int length,
 
 	LOCK(&ent->lock);
 
+	if (ent->usehook && (hook != NULL)) {
+		UNLOCK(&ent->lock);
+		return (hook(data, length, returned, flags));
+	}
+
 	remain = length;
 	buf = data;
 	total = 0;
@@ -627,7 +646,7 @@ isc_entropy_getdata(isc_entropy_t *ent, void *data, unsigned int length,
 	}
 
  partial_output:
-	memset(digest, 0, sizeof(digest));
+	isc_safe_memwipe(digest, sizeof(digest));
 
 	if (returned != NULL)
 		*returned = (length - remain);
@@ -639,8 +658,8 @@ isc_entropy_getdata(isc_entropy_t *ent, void *data, unsigned int length,
  zeroize:
 	/* put the entropy we almost extracted back */
 	add_entropy(ent, total);
-	memset(data, 0, length);
-	memset(digest, 0, sizeof(digest));
+	isc_safe_memwipe(data, length);
+	isc_safe_memwipe(digest, sizeof(digest));
 	if (returned != NULL)
 		*returned = 0;
 
@@ -697,6 +716,7 @@ isc_entropy_create(isc_mem_t *mctx, isc_entropy_t **entp) {
 	ent->refcnt = 1;
 	ent->initialized = 0;
 	ent->initcount = 0;
+	ent->usehook = ISC_FALSE;
 	ent->magic = ENTROPY_MAGIC;
 
 	isc_entropypool_init(&ent->pool);
@@ -750,9 +770,8 @@ destroysource(isc_entropysource_t **sourcep) {
 		break;
 	}
 
-	memset(source, 0, sizeof(isc_entropysource_t));
-
-	isc_mem_put(ent->mctx, source, sizeof(isc_entropysource_t));
+	isc_safe_memwipe(source, sizeof(*source));
+	isc_mem_put(ent->mctx, source, sizeof(*source));
 }
 
 static inline isc_boolean_t
@@ -818,8 +837,8 @@ destroy(isc_entropy_t **entp) {
 
 	DESTROYLOCK(&ent->lock);
 
-	memset(ent, 0, sizeof(isc_entropy_t));
-	isc_mem_put(mctx, ent, sizeof(isc_entropy_t));
+	isc_safe_memwipe(ent, sizeof(*ent));
+	isc_mem_put(mctx, ent, sizeof(*ent));
 	isc_mem_detach(&mctx);
 }
 
@@ -1233,6 +1252,11 @@ isc_entropy_usebestsource(isc_entropy_t *ectx, isc_entropysource_t **source,
 		use_keyboard == ISC_ENTROPY_KEYBOARDNO  ||
 		use_keyboard == ISC_ENTROPY_KEYBOARDMAYBE);
 
+#ifdef PKCS11CRYPTO
+	if (randomfile != NULL)
+		pk11_rand_seed_fromfile(randomfile);
+#endif
+
 #ifdef PATH_RANDOMDEV
 	if (randomfile == NULL) {
 		randomfile = PATH_RANDOMDEV;
@@ -1262,7 +1286,7 @@ isc_entropy_usebestsource(isc_entropy_t *ectx, isc_entropysource_t **source,
 
 		if (final_result != ISC_R_SUCCESS)
 			final_result = result;
-	}	
+	}
 
 	/*
 	 * final_result is ISC_R_SUCCESS if at least one source of entropy
@@ -1272,3 +1296,17 @@ isc_entropy_usebestsource(isc_entropy_t *ectx, isc_entropysource_t **source,
 	 */
 	return (final_result);
 }
+
+void
+isc_entropy_usehook(isc_entropy_t *ectx, isc_boolean_t onoff) {
+	REQUIRE(VALID_ENTROPY(ectx));
+
+	LOCK(&ectx->lock);
+	ectx->usehook = onoff;
+	UNLOCK(&ectx->lock);
+}
+
+void
+isc_entropy_sethook(isc_entropy_getdata_t myhook) {
+	hook = myhook;
+}
